==> xl-testview-server-1.3.2.zip: resultparser/testng-junitreportreporter.py <==
from parser.xunit import validate_files, get_root_node, parse_last_modified, parse_junit_test_results
from datetime import datetime
from com.xebialabs.xlt.plugin.api.resultparser import MalformedInputException

testng_time_format = '%d %b %Y %H:%M:%S %Z'

def testng_last_modified(file):
    root = get_root_node(file)
    timestamp = root.attrib["timestamp"]
    return int(((datetime.strptime(timestamp, testng_time_format) - datetime(1970,1,1)).total_seconds() * 1000))


def testng_result(testCase):
    failure = testCase.find("error")
    if failure is not None:
        return "FAILED"
    else:
        return "PASSED"


def testng_failure_reason(testCase):
    if testng_result(testCase) == "FAILED":
        failure = testCase.find("error")
        if failure is not None:
            return failure.attrib.get("message", "No failure reason").strip()
        else:
            raise MalformedInputException("Expected to have found a failure reason!")
    else:
        return None


def testng_validate_timestamp(root):
    timestamp = root.attrib["timestamp"]
    try:
        datetime.strptime(timestamp, testng_time_format)
        return True
    except ValueError:
        return False

validate_files(files, validate_timestamp=testng_validate_timestamp)

last_modified = parse_last_modified(files, extract_last_modified=testng_last_modified)

if not test_run_historian.isKnownKey(str(last_modified)):
    events = parse_junit_test_results(files, last_modified,
                                      extract_result=testng_result,
                                      extract_failure_reason=testng_failure_reason)
else:
    events = []

# Result holder should contain a list of test runs. A test run is a list of events

result_holder.result = [events] if events else []

==> xl-testview-server-1.4.2.zip: resultparser/testng-junitreportreporter.py <==
from parser.xunit import validate_files, get_root_node, parse_last_modified, parse_junit_test_results
from datetime import datetime
from com.xebialabs.xlt.plugin.api.resultparser import MalformedInputException

testng_time_format = '%d %b %Y %H:%M:%S %Z'

def testng_last_modified(file):
    root = get_root_node(file)
    timestamp = root.attrib["timestamp"]
    return int(((datetime.strptime(timestamp, testng_time_format) - datetime(1970,1,1)).total_seconds() * 1000))


def testng_result(test_case_node):
    failure = test_case_node.find("failure")
    error = test_case_node.find("error")
    skipped = test_case_node.find("skipped")
    if failure is not None or error is not None:
        return "FAILED"
    elif skipped is not None:
        return "OTHER"
    else:
        return "PASSED"


def testng_failure_reason(testCase):
    if testng_result(testCase) == "FAILED":
        failure = testCase.find("failure")
        error = testCase.find("error")
        if failure is not None:
            return failure.attrib.get("message", "No failure reason").strip()
        elif error is not None:
            return error.attrib.get("message", "No failure reason").strip()
        else:
            raise MalformedInputException("Expected to have found a failure reason!")
    else:
        return None


def testng_validate_timestamp(root):
    timestamp = root.attrib["timestamp"]
    try:
        datetime.strptime(timestamp, testng_time_format)
        return True
    except ValueError:
        return False

validate_files(files, validate_timestamp=testng_validate_timestamp)

last_modified = parse_last_modified(files, extract_last_modified=testng_last_modified)

if not test_run_historian.isKnownKey(str(last_modified)):
    events = parse_junit_test_results(files, last_modified,
                                      extract_result=testng_result,
                                      extract_failure_reason=testng_failure_reason)
else:
    events = []

# Result holder should contain a list of test runs. A test run is a list of events

result_holder.result = [events] if events else []
